@@ -106,7 +106,7 @@ async def fetch(client,url):
         return await resp.text()
 
 #############################VIPER API CALLS ################    
-async def tcp_echo_clientviper(message, loop,host,port,microserviceid):
+async def tcp_echo_clientviper(message, loop,host,port,microserviceid,timeout=0):
 
     hostarr=host.split(":")
     hbuf=hostarr[0]
@@ -123,7 +123,7 @@ async def tcp_echo_clientviper(message, loop,host,port,microserviceid):
     geturl=formaturlviper(message,host,microserviceid,hbuf,port) #host contains http:// or https://
     message="%s" % geturl 
 
-    async with ClientSession() as session:
+    async with ClientSession(timeout=timeout) as session:
         html = await fetch(session,message)
         return html
 
@@ -223,7 +223,7 @@ def viperhpdeoptimize(vipertoken,host,port,consumefrom,produceto,companyname,con
          "&partition="+str(partition)+"&offset="+str(offset)+
          "&hpdehost=" +hpdehost +"&hpdeport="+str(hpdeport))
     loop = asyncio.get_event_loop()
-    val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
+    val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid,timeout))
     return val
 
 def viperhpdetraining(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,viperconfigfile,
@@ -241,7 +241,11 @@ def viperhpdetraining(vipertoken,host,port,consumefrom,produceto,companyname,con
            "&hpdeport="+str(hpdeport)+"&brokerhost="+brokerhost+ "&offset="+str(offset) + "&viperconfigfile="+viperconfigfile +
            "&brokerport="+str(brokerport)+"&enabletls="+str(enabletls))
     loop = asyncio.get_event_loop()
-    val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
+#    future = asyncio.wait_for(loop.run_in_executor(None, time.sleep, 2), timeout)
+    try:
+       val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid,timeout))
+    except Exception as e:
+       print(e) 
     return val
 
 def viperproducetotopicstream(vipertoken,host,port,topic,producerid,offset,enabletls=0,delay=100,brokerhost='',brokerport=-999,microserviceid=''):
